@@ -13,7 +13,7 @@ wget http://nginx.org/download/nginx-{{ version }}.tar.gz
 tar zxvf *.tar.gz
 cd nginx-{{ version }}
 
-./configure --error-log-path=/var/log/nginx/error.log --http-log-path=/var/log/nginx/access.log --pid-path=/var/run/nginx.pid --conf-path=/etc/nginx/nginx.conf --sbin-path=/sbin --with-http_ssl_module --user=www-data --group=www-data
+./configure --error-log-path=/var/log/nginx/error.log --http-log-path=/var/log/nginx/access.log --pid-path=/var/run/nginx.pid --conf-path=/etc/nginx/nginx.conf --sbin-path=/sbin --with-http_ssl_module --user={{ user }} --group={{ user }}
 make
 
 if [ ! -d /etc/nginx ];
